# How to generate a PIP package?
- Change setup.cfg version
- py -m build
- py -m twine upload --skip-existing dist/*

Use this api key:
pypi-AgEIcHlwaS5vcmcCJDU2OGZkNWFjLTA1ZmMtNGU4ZS05OWQwLWM2NGU0MWQxYmYwZAACFlsxLFsic2NyYXBlYW55dGhpbmciXV0AAixbMixbIjU3MTA5MDEwLTdmYTEtNGMzNi1hZGVhLTg1NGZiYmI0OWYwMyJdXQAABiDFRt1RjykFgxkU-sMP3TCuOJRR_v2u0HLFNbvGIZGUDA

Reference: https://packaging.python.org/en/latest/tutorials/packaging-projects/